@@ -1,6 +1,6 @@
 package Net::OSCAR::Callbacks;
 BEGIN {
-  $Net::OSCAR::Callbacks::VERSION = '1.926_001';
+  $Net::OSCAR::Callbacks::VERSION = '1.927_001';
 }
 use strict;
 use warnings;
@@ -20,10 +20,10 @@ if($session->{rate_manage_mode} != OSCAR_RATE_MANAGE_NONE) {
 if($data{current} <= $data{disconnect}) {
 	$rate = RATE_DISCONNECT;
 	$worrisome = 1;
-} elsif($data{current} <= $data{limit}) {
+} elsif($data{limit} && $data{current} <= $data{limit}) {
 	$rate = RATE_LIMIT;
 	$worrisome = 1;
-} elsif($data{current} <= $data{alert}) {
+} elsif($data{alert} && $data{current} <= $data{alert}) {
 	$rate = RATE_ALERT;
 	if($data{current} - $data{limit} < 500) {
 		$worrisome = 1;
